@@ -18,15 +18,13 @@
 #ifndef _XPATHSELECT_H
 #define _XPATHSELECT_H
 
-#include <list>
-
 #include "node.h"
 
 namespace xpathselect
 {
     /// Search the node tree beginning with 'root' and return nodes that
     /// match 'query'.
-    NodeList SelectNodes(Node::Ptr const& root, std::string query);
+    extern "C" NodeList SelectNodes(Node::Ptr const& root, std::string query);
 }
 
 #endif
