@@ -154,6 +154,24 @@ TEST_F(TestTreeFixture, test_mixed_query_simple)
     }
 }
 
+TEST_F(TestTreeFixture, test_mixed_query_property_match)
+{
+    leaf_1_->AddProperty("visible", "True");
+    xpathselect::NodeList result = xpathselect::SelectNodes(root_, "/Root//Leaf[visible=True]");
+
+    ASSERT_EQ(1, result.size());
+    ASSERT_EQ(leaf_1_, result.front());
+}
+
+TEST_F(TestTreeFixture, test_search_node_with_wildcard_and_property)
+{
+    child_l1_->AddProperty("visible", "True");
+    xpathselect::NodeList result = xpathselect::SelectNodes(root_, "/Root//*[visible=True]");
+
+    ASSERT_EQ(1, result.size());
+    ASSERT_EQ(child_l1_, result.front());
+}
+
 TEST_F(TestTreeFixture, test_wildcard)
 {
     xpathselect::NodeList result = xpathselect::SelectNodes(root_, "/Root/*");
